@@ -3,17 +3,17 @@
 	library.dynam("realized")
    
     cat("Realized Library:  Realized Variance, Covariance, Correlation Estimation and Tools.\n")
-    cat("Available in R and S+.\n")
+   # cat("Available in R and S+.\n")
     cat(" R:  http://cran.r-project.org\n")
-    cat("S+:  http://csan.insightful.com\n")
-    cat("Copyright (C) 2008  Scott William Payseur, PhD <scott.payseur@gmail.com>\n\n")
+   # cat("S+:  http://csan.insightful.com\n")
+    cat("Copyright (C) 2010  Scott W. Payseur <scott.payseur@gmail.com>\n\n")
    
-    cat("This program is free software with restricted commercial use.\n")
-    cat("See LICENSE file for more details.\n")
+   # cat("This program is free software with restricted commercial use.\n")
+   # cat("See LICENSE file for more details.\n")
 
-    cat("This program is distributed in the hope that it will be useful,\n")
-    cat("but WITHOUT ANY WARRANTY; without even the implied warranty of\n")
-    cat("MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\n")
+   # cat("This program is distributed in the hope that it will be useful,\n")
+  #  cat("but WITHOUT ANY WARRANTY; without even the implied warranty of\n")
+  #  cat("MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\n")
 
     cat("Please report any bugs or feature requests to the author.  User's manual\n")
     cat("in the 'realized' library directory.\n\n\n")
@@ -170,18 +170,12 @@ rKernel.available <- function()
 }
 
 
-rv.kernel <- function(x, q, align.period=1, adj=TRUE, type=0, cts=TRUE, makeReturns=FALSE, ...)
+rv.kernel <- function(x, q, align.period=1, adj=TRUE, type=0, cts=TRUE, makeReturns=FALSE, rvargs=list(),...)
 {	
-
-   
-    if(class(args) != "function")
+    if(!is.null(rvargs$period))
     {
-    # version 2.8 bug fix
-    	if(!is.null(args$period))
-    	{
-    		align.period=args$period
-    	}
-     }
+    	align.period=rvargs$period
+    }
 	cdata <- .convertData(x, cts=cts, makeReturns=makeReturns)
 	x <- cdata$data
 	x <- .alignReturns(x, align.period)
@@ -341,23 +335,23 @@ rc.naive <- function(x, y,  period, align.period=1, cts=TRUE, makeReturns=FALSE,
 # Global Call 
 #
 #######################################
-rRealized.variance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor = FALSE, args = list(), cts=TRUE, makeReturns=FALSE)
+rRealized.variance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor = FALSE, rvargs = list(), cts=TRUE, makeReturns=FALSE)
 {
 	warning("Depricated:  call rRealizedVarianc")
-	rRealizedVariance(x=x, y=y, type=type, period=period, lags=lags, cor=cor, args=args, cts=cts, makeReturns=makeReturns)
+	rRealizedVariance(x=x, y=y, type=type, period=period, lags=lags, cor=cor, rvargs=rvargs, cts=cts, makeReturns=makeReturns)
 }
 
-rRealisedVariance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor = FALSE, args = list(), cts=TRUE, makeReturns=FALSE)
+rRealisedVariance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor = FALSE, rvargs = list(), cts=TRUE, makeReturns=FALSE)
 {
-	rRealizedVariance(x=x, y=y, type=type, period=period, lags=lags, cor=cor, args=args, cts=cts, makeReturns=makeReturns)
+	rRealizedVariance(x=x, y=y, type=type, period=period, lags=lags, cor=cor, rvargs=rvargs, cts=cts, makeReturns=makeReturns)
 }
 
 
-rRealizedVariance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor = FALSE, args = list(), cts=TRUE, makeReturns=FALSE)
+rRealizedVariance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor = FALSE, rvargs = list(), cts=TRUE, makeReturns=FALSE)
 {
-	if(!is.null(args$align.period))
+	if(!is.null(rvargs$align.period))
 	{
-	    align.period =args$align.period
+	    align.period =rvargs$align.period
 	}
 	else
 	{
@@ -382,14 +376,14 @@ rRealizedVariance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor
 	     			}
 	     			else
 	     			{
-	     				ans[i,j] <- .realized.variance(x=.getDataCol(x,j), y=NULL, type=type, period=period, lags=lags, args=args, cts=cts, makeReturns=makeReturns)
+	     				ans[i,j] <- .realized.variance(x=.getDataCol(x,j), y=NULL, type=type, period=period, lags=lags, rvargs=rvargs, cts=cts, makeReturns=makeReturns)
 	     			}
 	     		}
 	     		else
 	     		{
 	     		    if(j > i)
 	     		    {
-	     		    	ans[i,j] <- .realized.variance(x=.getDataCol(x,i), y=.getDataCol(x,j), type=type, period=period, lags=lags, args=args, cor=cor, cts=cts, makeReturns=makeReturns)
+	     		    	ans[i,j] <- .realized.variance(x=.getDataCol(x,i), y=.getDataCol(x,j), type=type, period=period, lags=lags, rvargs=rvargs, cor=cor, cts=cts, makeReturns=makeReturns)
 	     		    	ans[j,i]<-ans[i,j]
 	     		    }	
 	     		}
@@ -399,7 +393,7 @@ rRealizedVariance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor
 	}
 	else
 	{
-		ans <- .realized.variance(x=x, y=y, type=type, period = period, lags = lags, cor = cor, args = args, cts=cts, makeReturns=makeReturns)
+		ans <- .realized.variance(x=x, y=y, type=type, period = period, lags = lags, cor = cor, rvargs = rvargs, cts=cts, makeReturns=makeReturns)
 	}
 #	class(ans) <- "rRealized.variance"
 	ans
@@ -407,19 +401,19 @@ rRealizedVariance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor
 
 
 
-.realized.variance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor = FALSE, args = list(), cts=TRUE,makeReturns=FALSE)
+.realized.variance <- function(x, y=NULL, type="naive", period = 1, lags = 1, cor = FALSE, rvargs = list(), cts=TRUE,makeReturns=FALSE)
 {   
 	if(cor)
 	{
-		rvx <- do.call(paste("rv.", type, sep=""), c(args,list(x=x, q=lags, k=lags, period=period, cts=cts, makeReturns=makeReturns)))
-		rvy <- do.call(paste("rv.", type, sep=""), c(args,list(x=y, q=lags, k=lags, period=period, cts=cts, makeReturns=makeReturns)))
-		rcxy <- do.call(paste("rc.", type, sep=""), c(args,list(x=x, y=y, q=lags, k=lags, period=period, cts=cts, makeReturns=makeReturns)))
+		rvx <- do.call(paste("rv.", type, sep=""), c(rvargs=rvargs,list(x=x, q=lags, k=lags, period=period, cts=cts, makeReturns=makeReturns)))
+		rvy <- do.call(paste("rv.", type, sep=""), c(rvargs=rvargs,list(x=y, q=lags, k=lags, period=period, cts=cts, makeReturns=makeReturns)))
+		rcxy <- do.call(paste("rc.", type, sep=""),c(rvargs=rvargs,list(x=x, y=y, q=lags, k=lags, period=period, cts=cts, makeReturns=makeReturns)))
 		rcxy/(sqrt(rvx)*sqrt(rvy))
 	}
 	else
 	{
 		funct <- paste(ifelse(is.null(y), "rv.", "rc."), type, sep="")
-		do.call(funct, c(args, list(x=x, y=y, q=lags, k=lags, period=period, cts=cts, makeReturns=makeReturns)))	
+		do.call(funct, c(rvargs=rvargs, list(x=x, y=y, q=lags, k=lags, period=period, cts=cts, makeReturns=makeReturns)))	
 	}
 }
 
@@ -460,7 +454,7 @@ rCumSum <- function(x, period = 1, align.period=1, plotit=FALSE, type='l', cts =
 	ans
 }
 
-rScatterReturns <- function(x,y, period, align.period=1,numbers=FALSE,xlim= NULL, ylim=NULL, plotit=TRUE, pch=NULL, cts=TRUE, makeReturns=FALSE,...)
+rScatterReturns <- function(x,y, period, align.period=1,numbers=FALSE,xlim= NULL, ylim=NULL, plotit=TRUE, pch=NULL, cts=TRUE, makeReturns=FALSE, scale.size=0, col.change=FALSE,...)
 {
 
 	y<- .alignReturns(.convertData(y, cts=cts, makeReturns=makeReturns)$data, align.period)
@@ -490,25 +484,36 @@ rScatterReturns <- function(x,y, period, align.period=1,numbers=FALSE,xlim= NULL
 	
         	maxed <- max(mat)
 
-	for(i in 1:length(xs))
-	{
-    	for(j in 1:length(ys))
-    	{
-            if(mat[i,j]!=0)
-            {
-        		if(numbers)
-        		{
-				    
-					text(xs[i], ys[j],as.character(mat[i,j]), cex=.7)    	
-        		}
-        		else
-        		{
-                	points(jitter(xs[i],.001), jitter(ys[j],.001), pch=pch, cex=.7)    	
-        		}
-            }
+		for(i in 1:length(xs))
+		{
+    		for(j in 1:length(ys))
+    		{
+            	if(mat[i,j]!=0)
+            	{
+            		if(col.change)
+            		   thecol <- round(runif(1)*100,0)
+            		else
+            		   thecol = 1
+            		   
+        			if(numbers)
+        			{
+				     
+				    	if(scale.size ==0)
+							text(xs[i], ys[j],as.character(mat[i,j]), cex=.7, col=thecol)    	
+                        else
+                        	text(xs[i], ys[j], as.character(mat[i,j]), cex = (mat[i,j]/maxed) * scale.size, col=thecol)
+        			}
+        			else
+        			{
+        				if(scale.size ==0)
+                			points(xs[i], ys[j], pch=pch, cex=.7, col=thecol)    	
+                        else
+                			points(xs[i], ys[j], pch=pch, cex = (mat[i,j]/maxed) * scale.size, col=thecol)
+        			}
+            	}
 
-    	}
-	}
+    		}
+		}
 		return(NULL)
 	
 	}	
@@ -561,7 +566,7 @@ rc.hy <- function(x,y, period=1, align.period =1, cts = TRUE, makeReturns=FALSE,
 #
 # Signature Plot
 #
-rSignature <- function(range, x, y=NULL, type="naive", cor = FALSE, args = list(), xscale=1, iteration.funct="", iterations=NULL, plotit=FALSE, cts=TRUE, makeReturns=FALSE)
+rSignature <- function(range, x, y=NULL, type="naive", cor = FALSE, rvargs = list(), xscale=1, iteration.funct="", iterations=NULL, plotit=FALSE, cts=TRUE, makeReturns=FALSE)
 {
 	
     
@@ -570,7 +575,7 @@ rSignature <- function(range, x, y=NULL, type="naive", cor = FALSE, args = list(
 		x <- .convertData(x, cts=cts, makeReturns=makeReturns)$data
         y <- .convertData(y, cts=cts, makeReturns=makeReturns)$data
     	ans <- list(x=range*xscale, 
-        	 y=sapply(range, function(r, x, y, type, period, lags, cor, args){.realized.variance(x=x, y=y, type=type, period = r, lags = r, cor = cor, args = args)},x=x,y=y,type=type, cor=cor, args=args),
+        	 y=sapply(range, function(r, x, y, type, period, lags, cor, rvargs){.realized.variance(x=x, y=y, type=type, period = r, lags = r, cor = cor, rvargs = rvargs)},x=x,y=y,type=type, cor=cor, rvargs=rvargs),
         	 xgrid=range,
         	 type = type,
         	 cor = cor,
@@ -580,26 +585,26 @@ rSignature <- function(range, x, y=NULL, type="naive", cor = FALSE, args = list(
 	else
 	{
 	     ans <- sapply(1:length(iterations), 
-	     	function(i,iterations, iteration.funct,range, x, y, type, period, lags, cor, args, cts, makeReturns)
+	     	function(i,iterations, iteration.funct,range, x, y, type, period, lags, cor, rvargs, cts, makeReturns)
 	     	{
 	     		if(!is.null(y))
 	     		{
-	     	    	y.new <- do.call(iteration.funct, args=list(x=y, i=iterations[i], args=args))
+	     	    	y.new <- do.call(iteration.funct, args=list(x=y, i=iterations[i], rvargs=rvargs))
 	     		}
 	     		else
 	     		{
 	     	    	y.new <- NULL
 	        	}
 	     		sapply(range, 
-	     	 		function(r, x, y, type, period, lags, cor, args, cts, makeReturns)
+	     	 		function(r, x, y, type, period, lags, cor, rvargs, cts, makeReturns)
 	         		{
-	     	     		.realized.variance(x=x, y=y, type=type, period = r, lags = r, cor = cor, args = args)
+	     	     		.realized.variance(x=x, y=y, type=type, period = r, lags = r, cor = cor, rvargs = rvargs)
 	         		},
-	         	x=do.call(iteration.funct, args=list(x=x, i=iterations[i], args=args)), 
+	         	x=do.call(iteration.funct, args=list(x=x, i=iterations[i], rvargs=rvargs)), 
 	         	y=y.new,
 	         	type=type, 
 	         	cor=cor, 
-	         	args=args, 
+	         	rvargs=rvargs, 
 	         	cts=cts,
 	         	makeReturns=makeReturns)
 	     	},
@@ -610,7 +615,7 @@ rSignature <- function(range, x, y=NULL, type="naive", cor = FALSE, args = list(
 	     	 y=y,
 	     	 type=type, 
 	     	 cor=cor, 
-	     	 args=args, 
+	     	 rvargs=rvargs, 
 	     	 cts=cts,
 	     	 makeReturns=makeReturns)
              if(class(ans)!="numeric")
@@ -1005,7 +1010,11 @@ getReturns <- function(x)
 
 
 
-
+timeDate <- function(x, format)
+{
+   warning("This function is for SPLUS and does not work")
+   x
+}
 
 
 
